@@ -7,12 +7,13 @@ from flask import Blueprint, request, Flask, render_template
 from flask import jsonify
 from pydantic import BaseModel
 from pydantic.typing import Literal
+
 from . import utils, openapi, error
 from .error import ValidationError
 
 __all__ = ["SiwaDoc", "ValidationError"]
 
-__version__ = "0.1.3"
+__version__ = "0.1.4"
 
 SUPPORTED_UI = ('redoc', 'swagger', 'rapidoc')
 
@@ -35,7 +36,7 @@ class SiwaDoc:
         self.openapi_url = openapi_url
         self.openapi_version = "3.0.2"
         self.ui = ui
-        self.models: Dict[str: Dict] = {}
+        self.models: Dict[str, Dict] = {}
         if app is not None:
             self.init_app(app)
 
